@@ -23,10 +23,11 @@ test_that("lnt_diff warnings and errors", {
   #"'x' must contain a column with rel_dist information (see ?lnt_similarity)")
   expect_warning({
     class(duplicates.df) <- "data.frame"
-    lnt_diff(x = duplicates.df,
-             min = 0.18,
-             max = 0.30,
-             output_html = TRUE)
+    diff <- capture_output( 
+      lnt_diff(x = duplicates.df,
+               min = 0.18,
+               max = 0.30,
+               output_html = TRUE))
   },
   "'x' should be an object returned by lnt_similarity().")
 })
